pub struct ExponentialMovingAverage<const FACTOR: usize> {
count: usize,
average: f64,
}Expand description
An exponential moving average calculator.
Based on the formula:
EMA_t = EMA_{t-1} + (Value_t - EMA_{t-1}) / min(t, FACTOR)
this object maintains a running average that emphasizes recent values more heavily and creates a smooth long-tailed averaging effect over time.
Fields
count: usizeaverage: f64Implementations